crikit.data.tests package — CRIKit2 0.4.3 documentation

# crikit.data.tests package

## Submodules

## crikit.data.tests.test_hsi module

crikit.data.tests.test_hsi.make_datasets()

  Setups and tears down a series of datasets

crikit.data.tests.test_hsi.test_hsi_to_hsi(make_datasets)

  Import an hsi into an hsi

crikit.data.tests.test_hsi.test_hsi_to_hsi_rng(make_datasets)

  Import an hsi into an hsi – defined range

crikit.data.tests.test_hsi.test_mean_axes_static()

  Ensure mean_axes_static raises an error

crikit.data.tests.test_hsi.test_reshape_axes_static(make_datasets)

  Test reshape axes static method

crikit.data.tests.test_hsi.test_spectra_to_hsi(make_datasets)

  Import spectra into an hsi

crikit.data.tests.test_hsi.test_spectra_to_hsi_rng(make_datasets)

  Import spectra into an hsi – defined range

crikit.data.tests.test_hsi.test_spectrum_to_hsi(make_datasets)

  Import a spectrum into an hsi

crikit.data.tests.test_hsi.test_spectrum_to_hsi_rng(make_datasets)

  Import a spectrum into an hsi – defined range

## crikit.data.tests.test_mosaic module

crikit.data.tests.test_mosaic.test_2D_uniform_obj()

crikit.data.tests.test_mosaic.test_3D_crop_transpose_flips()

  Test a 2D dataset with cropped rows and columns

crikit.data.tests.test_mosaic.test_3D_crop_transpose_flips_2()

  Test a 2D dataset with cropped rows and columns (asymmetrically)

crikit.data.tests.test_mosaic.test_3D_uniform_obj()

crikit.data.tests.test_mosaic.test_big_to_small_2d()

crikit.data.tests.test_mosaic.test_big_to_small_2d_2()

crikit.data.tests.test_mosaic.test_big_to_small_3d()

crikit.data.tests.test_mosaic.test_big_to_small_3d_2()

crikit.data.tests.test_mosaic.test_big_to_small_3d_output_given()

crikit.data.tests.test_mosaic.test_blank()

crikit.data.tests.test_mosaic.test_crop_2D()

  Test a 2D dataset with cropped rows and columns

crikit.data.tests.test_mosaic.test_crop_3D()

  Test a 2D dataset with cropped rows and columns

crikit.data.tests.test_mosaic.test_err_wrong_dim()

crikit.data.tests.test_mosaic.test_err_wrong_dim_append()

## crikit.data.tests.test_mosaic_hdf module

crikit.data.tests.test_mosaic_hdf.hdf_dataset2()

  Setups and tears down a sample HDF5 file

crikit.data.tests.test_mosaic_hdf.test_big_to_small_3d_output_given()

crikit.data.tests.test_mosaic_hdf.test_big_to_small_3d_output_given_crop()

  3D big dataset, divied up into small chunks – WITH CROPPING

crikit.data.tests.test_mosaic_hdf.test_big_to_small_3d_output_given_crop_transpose_flips()

  3D big dataset, divied up into small chunks – WITH CROPPING, TRANSPOSING AND FLIPPING H & V

  Note: This test does not assert anything, but rather just ensures the methods can run without raising errors

crikit.data.tests.test_mosaic_hdf.test_hdf2(hdf_dataset2)

## crikit.data.tests.test_spectra module

crikit.data.tests.test_spectra.make_datasets()

  Setups and tears down a series of datasets

crikit.data.tests.test_spectra.test_hsi_to_spectra(make_datasets)

  Import an hsi into spectra

crikit.data.tests.test_spectra.test_hsi_to_spectra_rng(make_datasets)

  Import an hsi into spectra – defined range

crikit.data.tests.test_spectra.test_mean_axes_static()

  Ensure mean_axes_static raises an error

crikit.data.tests.test_spectra.test_reshape_axes_static(make_datasets)

  Test reshape axes static method

crikit.data.tests.test_spectra.test_spectra_to_spectra(make_datasets)

  Import a spectrum into a spectrum

crikit.data.tests.test_spectra.test_spectra_to_spectra_rng(make_datasets)

  Import spectra into spectra – defined range

crikit.data.tests.test_spectra.test_spectrum_to_spectra(make_datasets)

  Import a spectrum into a spectrum

crikit.data.tests.test_spectra.test_spectrum_to_spectra_rng(make_datasets)

  Import spectrum into spectra – defined range

## crikit.data.tests.test_spectrum module

crikit.data.tests.test_spectrum.make_datasets()

  Setups and tears down a series of datasets

crikit.data.tests.test_spectrum.test_hsi_to_spectrum(make_datasets)

  Import hsi into a spectrum

crikit.data.tests.test_spectrum.test_hsi_to_spectrum_rng(make_datasets)

  Import an hsi into a spectrum – defined range

crikit.data.tests.test_spectrum.test_mean_axes_static(make_datasets)

  Import a spectrum into a spectrum

crikit.data.tests.test_spectrum.test_spectra_to_spectrum(make_datasets)

  Import spectra into a spectrum

crikit.data.tests.test_spectrum.test_spectra_to_spectrum_rng(make_datasets)

  Import spectra into a spectrum – defined range

crikit.data.tests.test_spectrum.test_spectrum_to_spectrum(make_datasets)

  Import a spectrum into a spectrum

crikit.data.tests.test_spectrum.test_spectrum_to_spectrum_rng(make_datasets)

  Import a spectrum into a spectrum – defined range

## crikit.data.tests.~test_data_indexing module

## Module contents